==> kubernetes-model-1.0.54-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressTLSBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class IngressTLSBuilder extends IngressTLSFluentImpl<IngressTLSBuilder> implements VisitableBuilder<IngressTLS,IngressTLSBuilder>{

    IngressTLSFluent<?> fluent;
    Boolean validationEnabled;

    public IngressTLSBuilder(){
            this(true);
    }
    public IngressTLSBuilder(Boolean validationEnabled){
            this(new IngressTLS(), validationEnabled);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent){
            this(fluent, true);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IngressTLS(), validationEnabled);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,IngressTLS instance){
            this(fluent, instance, true);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,IngressTLS instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withHosts(instance.getHosts()); 
            fluent.withSecretName(instance.getSecretName()); 
            this.validationEnabled = validationEnabled; 
    }
    public IngressTLSBuilder(IngressTLS instance){
            this(instance,true);
    }
    public IngressTLSBuilder(IngressTLS instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withHosts(instance.getHosts()); 
            this.withSecretName(instance.getSecretName()); 
            this.validationEnabled = validationEnabled; 
    }

    public IngressTLS build(){
            IngressTLS buildable = new IngressTLS(fluent.getHosts(),fluent.getSecretName());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IngressTLSBuilder that = (IngressTLSBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressTLSBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class IngressTLSBuilder extends IngressTLSFluentImpl<IngressTLSBuilder> implements VisitableBuilder<IngressTLS,IngressTLSBuilder>{

    IngressTLSFluent<?> fluent;
    Boolean validationEnabled;

    public IngressTLSBuilder(){
            this(true);
    }
    public IngressTLSBuilder(Boolean validationEnabled){
            this(new IngressTLS(), validationEnabled);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent){
            this(fluent, true);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IngressTLS(), validationEnabled);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,IngressTLS instance){
            this(fluent, instance, true);
    }
    public IngressTLSBuilder(IngressTLSFluent<?> fluent,IngressTLS instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withHosts(instance.getHosts()); 
            fluent.withSecretName(instance.getSecretName()); 
            this.validationEnabled = validationEnabled; 
    }
    public IngressTLSBuilder(IngressTLS instance){
            this(instance,true);
    }
    public IngressTLSBuilder(IngressTLS instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withHosts(instance.getHosts()); 
            this.withSecretName(instance.getSecretName()); 
            this.validationEnabled = validationEnabled; 
    }

    public IngressTLS build(){
            IngressTLS buildable = new IngressTLS(fluent.getHosts(),fluent.getSecretName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IngressTLSBuilder that = (IngressTLSBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
